pub enum ConnectionArgs {
Quic {
hostname: String,
prefer_ipv6: bool,
validate_tls: bool,
},
Tcp {
hostname: String,
prefer_ipv6: bool,
},
Srv {
hostname: String,
prefer_ipv6: bool,
validate_tls: bool,
use_quic: bool,
},
Mpsc(u64),
}Variants
Quic
hostname: (hostname|ip):[<port>]
Tcp
hostname: (hostname|ip):[<port>]
Srv
SRV lookup
SRV lookups can not contain a port, but will be able to connect to configured port automatically. If a connection with a port is given, this will gracefully fall back to TCP.
Mpsc(u64)
Implementations
Sourceimpl ConnectionArgs
impl ConnectionArgs
const DEFAULT_PORT: u16 = 14004